amostra.sample_data package
===========================

Submodules
----------

amostra.sample_data.generic_sample module
-----------------------------------------

.. automodule:: amostra.sample_data.generic_sample
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: amostra.sample_data
    :members:
    :undoc-members:
    :show-inheritance:
